@@ -1,28 +1,15 @@
-/***************************************************************************
- *   Copyright © 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "DiscoverNotifier.h"
 #include "BackendNotifierFactory.h"
 #include <QDebug>
-#include <QDBusInterface>
-#include <QDBusPendingReply>
+#include <QDBusConnection>
+#include <QDBusPendingCall>
+#include <QDBusMessage>
 #include <QNetworkConfigurationManager>
 #include <KLocalizedString>
 #include <KNotification>
@@ -206,8 +193,12 @@ void DiscoverNotifier::showRebootNotification()
 
 void DiscoverNotifier::reboot()
 {
-    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
-    interface.asyncCall(QStringLiteral("logout"), 1, 1, 2); // Options: confirm first | reboot | force
+    QDBusConnection::sessionBus().asyncCall(
+        QDBusMessage::createMethodCall(QStringLiteral("org.kde.LogoutPrompt"),
+                                       QStringLiteral("/LogoutPrompt"),
+                                       QStringLiteral("org.kde.LogoutPrompt"),
+                                       QStringLiteral("promptReboot"))
+    );
 }
 
 void DiscoverNotifier::foundUpgradeAction(UpgradeAction* action)
